pub struct Manager { /* private fields */ }Expand description
SIGINT manager.
Setting up the manager ensures that the interrupt signal will be
converted to an application exit, but also that there is a way to
suppress this behavior (via Manager::suppress).
Implementations